@@ -3,6 +3,7 @@ package org.jmx4perl.it;
 import javax.management.MBeanRegistration;
 import javax.management.ObjectName;
 import javax.management.MBeanServer;
+import javax.management.MalformedObjectNameException;
 
 /*
  * jmx4perl - WAR Agent for exporting JMX via JSON
@@ -47,7 +48,7 @@ public class AttributeChecking implements AttributeCheckingMBean, MBeanRegistrat
         reset();
     }
 
-    public void reset() {
+    public final void reset() {
         state = false;
         idx = 0;
     }
@@ -66,14 +67,31 @@ public class AttributeChecking implements AttributeCheckingMBean, MBeanRegistrat
         return null;
     }
 
-    public ObjectName preRegister(MBeanServer pMBeanServer, ObjectName pObjectName) throws Exception {
+    public long getBytes() {
+        // 3.5 MB
+        return 3 * 1024 * 1024 +  1024 * 512;
+    }
+
+    public float getLongSeconds() {
+        // 2 days
+        return 60*60*24*2;
+    }
+
+    public double getSmallMinutes() {
+        // 10 ms
+        return  1f/60 * 0.01;
+    }
+
+    // ============================================================================
+
+    public ObjectName preRegister(MBeanServer pMBeanServer, ObjectName pObjectName) throws MalformedObjectNameException {
         return new ObjectName(name);
     }
 
     public void postRegister(Boolean pBoolean) {
     }
 
-    public void preDeregister() throws Exception {
+    public void preDeregister() {
     }
 
     public void postDeregister() {
