@@ -102,7 +102,7 @@ public class ObjectToJsonConverter {
             Object jsonResult = extractObject(pValue,extraStack,true);
             JSONObject jsonObject = new JSONObject();
             jsonObject.put("value",jsonResult);
-            jsonObject.put("request",pRequest);
+            jsonObject.put("request",pRequest.toJSON());
             return jsonObject;
         } finally {
             clearContext();
@@ -174,7 +174,9 @@ public class ObjectToJsonConverter {
             v = pServletConfig.getInitParameter("maxObjects");
             hardMaxObjects = v != null ? Integer.parseInt(v) : 0;
         } else {
-            hardMaxDepth = hardMaxCollectionSize = hardMaxObjects = 0;
+            hardMaxDepth = 0;
+            hardMaxCollectionSize = 0;
+            hardMaxObjects = 0;
         }
     }
 
